using BepInEx;
using BepInEx.Configuration;
using BepInEx.Logging;
using MewMod.Hooks;
using HarmonyLib;
using LobbyCompatibility.Attributes;
using LobbyCompatibility.Enums;

namespace MewMod;

[BepInPlugin(MyPluginInfo.PLUGIN_GUID, MyPluginInfo.PLUGIN_NAME, MyPluginInfo.PLUGIN_VERSION)]
[BepInDependency("BMX.LobbyCompatibility", BepInDependency.DependencyFlags.HardDependency)]
[LobbyCompatibility(CompatibilityLevel.ClientOnly, VersionStrictness.None)]
public class MewMod : BaseUnityPlugin
{
    public static MewMod Instance { get; private set; } = null!;
    internal new static ManualLogSource Logger { get; private set; } = null!;

    private void Awake()
    {
        Logger = base.Logger;
        Instance = this;
        
        var configEnabled = base.Config.Bind(
            "General",
            "lessScary",
            "false",
            "Set to true (case sensitive) to make the game less scary."
        );

        if (configEnabled.Value == "true") {
            Hook();
        } else {
            Logger.LogWarning("Mod disabled, scary things ENABLED!!!! (Check ones config file!!)");
        }

        Logger.LogInfo($"{MyPluginInfo.PLUGIN_GUID} v{MyPluginInfo.PLUGIN_VERSION} has loaded,, awawawawa");
    }

    internal static void Hook()
    {
        Logger.LogDebug("Hooking...");
        On.MaskedPlayerEnemy.killAnimation += DisableMaskedJumpscare.DisableJumpscarePatch;
        On.SoundManager.SetFearAudio += DisableFearSounds.DisableFearSoundsPatch;
        On.SoundManager.PlayNonDiageticSound += DisableNonDiageticSounds.DisableNonDiageticSoundsPatch;
        On.SoundManager.PlayAmbientSound += DisableScaryAmbientSounds.DisableScaryAmbientSoundsPatch;
        On.SoundManager.PlayAmbienceClipClientRpc += DisableScaryAmbientSounds.DisableScaryAmbientSoundsRpcPatch;
        Logger.LogDebug("Finished Hooking!");
    }

    internal static void Unhook()
    {
        Logger.LogDebug("Unhooking...");
        On.MaskedPlayerEnemy.killAnimation -= DisableMaskedJumpscare.DisableJumpscarePatch;
        On.SoundManager.SetFearAudio -= DisableFearSounds.DisableFearSoundsPatch;
        On.SoundManager.PlayNonDiageticSound -= DisableNonDiageticSounds.DisableNonDiageticSoundsPatch;
        On.SoundManager.PlayAmbientSound -= DisableScaryAmbientSounds.DisableScaryAmbientSoundsPatch;
        On.SoundManager.PlayAmbienceClipClientRpc -= DisableScaryAmbientSounds.DisableScaryAmbientSoundsRpcPatch;
        Logger.LogDebug("Finished Unhooking!");
    }
}
